"""
    @file   lcd.py
    @brief  test de l'afficheur LCD

    @version   1.0
    @author    GS
    @date      12/12/2022
    @remark    https://docs.micropython.org/en/latest/library/machine.Pin.html
"""

# importation bibliothèque
from machine import Pin, SoftI2C

# déclaration des constantes (broches)
SDA_PIN   = 0
SCL_PIN   = 1
FREQUENCY = 400000

LCD_CMD_MODE = 0x7C 	# enters command mode 
LCD_BLANK    = 0x2D 	# blanks the LCD and sets the cursor to the beginning

def display(message : str) -> bool:
    """ Affichage sur LCD I2C
    @param	message -- message à afficher
    @return	True si afficheur trouvé, False sinon
    """
    bus = SoftI2C(scl=Pin(SCL_PIN), sda=Pin(SDA_PIN), freq=FREQUENCY)
    if len(bus.scan()) == 0:
        return False

    address = bus.scan()[0] 					# recherhce de l'@ I2C du capteur ADT7410
    bus.writeto(address, bytes(LCD_CMD_MODE))
    bus.writeto(address, bytes(LCD_BLANK))
    bus.writeto(address, message)
    return True

### Programme Principal  ###
if display("hello world") == False:
    print("can't find the sensor")