"""
    @file   temperature.py
    @brief  mesure de température par capteur I2C

    @version   1.0
    @author    profs TSIN
    @date      12/12/2022
    @remark    https://docs.micropython.org/en/latest/library/machine.I2C.html
"""

# importation bibliothèque
from machine import Pin, SoftI2C
from utime import sleep

SDA_PIN   = 0
SCL_PIN   = 1
FREQUENCY = 400000

def read_temperature(register : int = 0x00) -> float:
    """ lecture capteur temperature I2C
    @param	register -- registre @ du capteur ADT7410
    @return	température si lecture ok, -999 sinon
    """
    bus = SoftI2C(scl=Pin(SCL_PIN), sda=Pin(SDA_PIN), freq=FREQUENCY)
    if len(bus.scan()) == 0:
        return -999

    address = bus.scan()[0] 					# recherche de l'@ I2C du capteur ADT7410
    #bus.writeto(address, bytes(0x40))			# Configuration de la résolution du capteur
    bus.writeto_mem(address, register, bytes(0x40))

    reg_status   = 0x02
    reg_lsb_read = 0x01
    reg_msb_read = 0x00

    # boucle d'attente que l'acquisition se termine
    while (bus.readfrom_mem(address, reg_status, 1) and 0x80) == 0:
        pass

    LSB = bus.readfrom_mem(address, reg_lsb_read, 1)    	# Lecture registre température
    MSB = bus.readfrom_mem(address, reg_msb_read, 1)

    temperature = (int(MSB[0]) << 8 | int(LSB[0])) >> 3    	# Mise en forme de la valeur bin des registres de températures
    return temperature * 0.0625                        	    # Calcul de la valeur de la température

#main
temperature = 0
while temperature != -999:
    temperature = read_temperature()
    if temperature == -999:
        print("can't find the sensor")
    else:
        print (temperature, "°C")
        sleep(1)
