#!/usr/bin/env python3
# coding: utf-8

"""
    @file   admin.py
	@brief	projet emess, administration clients/menus

    @version   1.0
    @author    PG
    @date      04/06/2022
    @remark
"""

from flask import Flask, render_template, request
import time
import read_message as i10n
import dal as dal
import date as calendar


app = Flask(__name__, template_folder='tpl')

@app.route('/', methods=['GET'])
def index():
    """ admin home page """
    try:
        lang = request.args['lang']
    except KeyError:
        lang = "fr"

    msg = i10n.message_read(lang)

    return render_template(
        "admin.html",
        lang=lang, 
        title=msg['MSG_TITLE'], customer=msg['MSG_CLIENT'], menu=msg['MSG_MENU'], new=msg['MSG_NEW'])

@app.route('/href_customer', methods=['POST', 'GET'])
def customer_validation():
    """ gestion des clients """
    try:
        lang  = request.args['lang']
    except KeyError:
        lang  = request.form['lang']
    row   = []
    modal = False
    modal_title = ""

    msg   = i10n.message_read(lang)
    data  = dal.DAL("./data/emess")
    
    try:    # suppression
        id = request.args['del']
        data.delete_person(id)
        data.delete_orders_from(id)
    except KeyError:
        pass

    try:    # ajout
        if request.args['add']:
            modal = True
            modal_title = msg['MSG_NEW']
    except KeyError:
        pass
    
    try:    # modification
        id = request.args['edit']
        row = data.select_person(int(id))
        modal = True
        modal_title = msg['MSG_UPDATE']
    except KeyError:
        pass
    
    try:    # validation
        if request.form['submit'] == "submit":
            badge = request.form['badge']
            if badge != "":
                data.update_person([(request.form['name'], request.form['fname'], request.form['rank'], badge)])
            else:
                data.insert_person([(request.form['name'], request.form['fname'], request.form['rank'])])
    except KeyError:
        pass

    ranks = []
    for i in msg['MSG_RANKS'].split(','):
        if len(row) and row['rank'] == i:
            selected = "selected"
        else:
            selected = ""
        ranks.append({'value':i, 'selected':selected})
        
    posts = []
    try:
        posts =  data.select_all_person()
    except ValueError:
        pass
    return render_template(
        "customer.html",
        lang=lang, posts=posts, ranks=ranks, modal=modal, modal_title=modal_title, row=row,
        title=msg['MSG_TITLE'], save=msg['MSG_SAVE'], cancel=msg['MSG_CANCEL'],
        name=msg['MSG_NAME'], fname=msg['MSG_FNAME'], badge=msg['MSG_BADGE'], rank=msg['MSG_RANK'])

@app.route('/href_menu', methods=['POST', 'GET'])
def menu_validation():
    """ gestion des menus """
    try:
        lang  = request.args['lang']
    except KeyError:
        lang  = request.form['lang']
    row   = []

    msg   = i10n.message_read(lang)
    data  = dal.DAL("./data/emess")
    
    try:    # validation
        if request.form['submit'] == "submit":
            for day in msg['MSG_DAYS'].split(','):
                idmenu, date, menu = request.form['id_'+day], request.form['date_'+day], request.form[day]
                if int(idmenu):
                    data.update_menu([(date, menu, idmenu)])
                else:
                    data.insert_menu([(date, menu)])
    except KeyError:
        pass

    posts = []
    try:
        day = 0
        for date in calendar.get_dotw():
            menu  = data.select_motd(date)
            count = len( data.select_ootd(date) )
            if menu != []:
                posts.append({'day':msg['MSG_DAYS'].split(',')[day], 'date':date, 'id':menu[0]['id'], 'menu':menu[0]['menu'], 'count':count})
            else:
                posts.append({'day':msg['MSG_DAYS'].split(',')[day], 'date':date, 'id':0, 'menu':'', 'count':count})
            day += 1
    except ValueError:
        pass
    return render_template(
        "menu.html",
        lang=lang, posts=posts,
        title=msg['MSG_TITLE'], date=msg['MSG_WEEK']+' '+calendar.get_dotw()[0], save=msg['MSG_SAVE'])

#main
app.run(debug=True)
