#!/usr/bin/env python3
# coding: utf-8

"""
    @file   dal.class.py
	@brief	objet DAL

    @version   1.0
    @author    BC
    @date      04/06/2022
    @remark
"""

import sqlite3

class DAL:
    __dbh    = None    # database handler
    __cursor = None    # curseur sur les tables

    def __init__(self, database : str):
        self.__dbh = sqlite3.connect(database+".db")
        self.__cursor = self.__dbh.cursor()

    def close(self):
        self.__cursor.close()
        self.__dbh.close()

    def insert_person(self, data : list) -> bool:
        """
		@brief  methode qui enregistre les informations d'une personne
		@param  data -- liste des données d'une personne
        @return True si insertion réussie, False sinon
		"""
        try:
            self.__cursor.executemany("INSERT INTO personnels VALUES(NULL, ?, ?, ?)", data)
            self.__dbh.commit()
            return True
        except sqlite3.IntegrityError:
            return False

    def delete_person(self, id : int) -> bool:
        """
		@brief  methode qui supprime une personne
		@param  data -- ID de la personne
        @return True si suppression réussie, False sinon
		"""
        try:
            self.__cursor.execute("DELETE FROM personnels WHERE ID = '"+ str(id) +"'")
            self.__dbh.commit()
            return True
        except sqlite3.OperationalError:
            return False

    def update_person(self, data : list) -> bool:
        """
		@brief  methode qui modifie les informations d'une personne
		@param  data -- dictionnaire des données d'une personne
        @return True
		"""
        self.__cursor.executemany("UPDATE personnels SET nom = ?, prenom = ?, grade = ? WHERE ID = ?", data)
        self.__dbh.commit()
        return True

    def select_person(self, id : int) -> dict:
        """
		@brief  methode qui récupère les informations d'une personne
		@param  id -- ID du personnel
		@return dictionnaire des données de la personne
		"""
        request  = "SELECT * FROM personnels "
        request += "WHERE ID = '"+ str(id) +"'"
        try:
            id, name, fname, rank = self.__cursor.execute(request).fetchall()[0]
            return { 'id':id, 'name':name, 'fname':fname, 'rank':rank }
        except IndexError:
            return {}

    def select_all_person(self, letter : str = "") -> list:
        """
		@brief  methode qui récupère les informations de la table personnels
		@param  letter -- filtre sur 1ère lettre du nom (pas de filtre si chaine vide)
		@return liste de dictionnaires des enregistrements de la table personnels
		"""
        request  = "SELECT * FROM personnels "
        request += "WHERE nom LIKE '"+letter+"%' " if letter != "" else ""
        request += "ORDER BY nom, prenom"
        try:
            persons = []
            for id, name, fname, rank in self.__cursor.execute(request).fetchall():
                persons.append( { 'id':id, 'name':name, 'fname':fname, 'rank':rank } )
            return persons
        except IndexError:
            return []

    def insert_menu(self, data : list):
        """
		@brief  methode qui enregistre les informations d'un menu
		@param  data -- liste des données du menu
        @return True si insertion réussie, False sinon
		"""
        try:
            self.__cursor.executemany("INSERT INTO menus VALUES(NULL, ?, ?)", data)
            self.__dbh.commit()
            return True
        except sqlite3.IntegrityError:
            return False

    def delete_menu(self, id : int) -> bool:
        """
		@brief  methode qui supprime un menu
		@param  data -- ID du menu
        @return True si suppression réussie, False sinon
		"""
        try:
            self.__cursor.execute("DELETE FROM menus WHERE ID = '"+ str(id) +"'")
            self.__dbh.commit()
            return True
        except sqlite3.OperationalError:
            return False

    def update_menu(self, data : list):
        """
		@brief  methode qui modifie les informations d'un menu
		@param  data -- liste des données d'un menu
        @return True
		"""
        self.__cursor.executemany("UPDATE menus SET date = ?, menu = ? WHERE ID = ?", data)
        self.__dbh.commit()
        return True

    def select_menu(self, id : int) -> dict:
        """
		@brief  methode qui récupère un menu
		@param  id -- ID du menu
		@return dictionnaire des données du menu
		"""
        request  = "SELECT * FROM menus "
        request += "WHERE ID = " + str(id)
        try:
            id, date, menu = self.__cursor.execute(request).fetchall()[0]
            return { 'id':id, 'date':date, 'menu':menu }
        except IndexError:
            return {}

    def select_motw(self, begin : str, end : str) -> dict:
        """
		@brief  methode qui récupère les menus de la semaine
		@param  begin -- date de début
		@param  end -- date de fin
		@return liste de dictionnaires des données des menus
		"""
        request  = "SELECT * FROM menus "
        request += "WHERE date >= '" + begin + "' AND date <= '" + end + "' "
        request += "ORDER BY date"
        try:
            menus = []
            for id, date, menu in self.__cursor.execute(request).fetchall():
                menus.append( { 'id':id, 'date':date, 'menu':menu } )
            return menus
        except IndexError:
            return []

    def select_motd(self, date : str) -> dict:
        """
		@brief  methode qui récupère le menu du jour
		@param  date -- date du jour
		@return liste de dictionnaires des données du menu
		"""
        return self.select_motw(date, date)

    def insert_order(self, data : list):
        """
		@brief  methode qui enregistre une réservation
		@param  data -- liste des données de la réservation
        @return True si insertion réussie, False sinon
		"""
        try:
            self.__cursor.executemany("INSERT INTO reservations VALUES(NULL, ?, ?, NULL)", data)
            self.__dbh.commit()
            return True
        except sqlite3.IntegrityError:
            return False

    def update_order(self, data : list):
        """
		@brief  methode qui enregistre l'heure de récption d'un repas
		@param  data -- liste des données de la réservation
        @return True si modification réussie, False sinon
		"""
        try:
            self.__cursor.executemany("UPDATE reservations SET reception = ? WHERE ID = ?", data)
            self.__dbh.commit()
            return True
        except sqlite3.IntegrityError:
            return False

    def delete_order(self, id : int):
        """
		@brief methode qui supprime une réservation
		@param data -- ID de la réservation
        @return True si suppression réussie, False sinon
		"""
        try:
            self.__cursor.execute("DELETE FROM reservations WHERE ID = '"+ str(id) +"'")
            self.__dbh.commit()
            return True
        except sqlite3.OperationalError:
            return False

    def delete_orders_from(self, id : int):
        """
		@brief methode qui supprime les réservations d'une personne
		@param data -- ID de la personne
		@return True si suppression réussie, False sinon
		"""
        try:
            self.__cursor.execute("DELETE FROM reservations WHERE IDpersonnel = '"+ str(id) +"'")
            self.__dbh.commit()
            return True
        except sqlite3.OperationalError:
            return False

    def select_ootd(self, date : str) -> list:
        """
		@brief  methode qui récupère les réservations du jour (pour la cuisine)
		@param  begin -- date de début
		@param  end -- date de fin
		@return liste des données des réservations
		"""
        request  = "SELECT personnels.nom, personnels.prenom, personnels.grade, reservations.reception "
        request += "FROM personnels, menus, reservations "
        request += "WHERE menus.date = '" + date + "' "
        request += "AND menus.ID = reservations.IDmenu "
        request += "AND personnels.ID = reservations.IDpersonnel "
        request += "ORDER BY personnels.nom"
        try:
            orders = []
            for name, fname, rank, received in self.__cursor.execute(request).fetchall():
                orders.append( { 'name':name, 'fname':fname, 'rank':rank, 'received':received } )
            return orders
        except IndexError:
            return []

    def select_ootw(self, id : int, begin : str, end : str) -> list:
        """
		@brief  methode qui récupère les réservations de la semaine (pour le client)
		@param  id -- ID du personnel qui a réservé
		@param  begin -- date de début
		@param  end -- date de fin
		@return liste de dictionnaires des réservations du client sur la semaine
		"""
        request  = "SELECT reservations.ID, menus.ID, reservations.reception "
        request += "FROM personnels, menus, reservations "
        request += "WHERE personnels.ID = '" + str(id) + "' "
        request += "AND menus.date BETWEEN '" + begin + "' AND '" + end + "' "
        request += "AND reservations.IDpersonnel = personnels.ID "
        request += "AND reservations.IDmenu = menus.ID "
        request += "ORDER BY menus.date"
        try:
            orders = []
            for IDorder, IDmenu, received in self.__cursor.execute(request).fetchall():
                orders.append( { 'IDorder':IDorder, 'IDmenu':IDmenu, 'received':received } )
            return orders
        except IndexError:
            return []

# TU
if __name__ == "__main__":
    #fixture
    dal = DAL("../2-serveur/data/emess")

    assert dal.select_all_person() == [{'id':1, 'name':'DUFOUR', 'fname':'ALEX', 'rank':'ADJ'}]
    assert dal.select_person(1) == { 'id':1, 'name':'DUFOUR', 'fname':'ALEX', 'rank':'ADJ' }
    assert dal.select_person(2) == {}
    assert dal.insert_person([('BLANC', 'CELINE', 'ADC')])
    assert dal.insert_person([('BLANC', 'CELINE', 'ADC')]) == False
    assert dal.select_all_person('D') == [{'id':1, 'name':'DUFOUR', 'fname':'ALEX', 'rank':'ADJ'}]
    assert dal.select_all_person() == [{'id':2, 'name':'BLANC', 'fname':'CELINE', 'rank':'ADC'}, {'id':1, 'name':'DUFOUR', 'fname':'ALEX', 'rank':'ADJ'}]
    assert dal.update_person([('BLAND', 'CELINA', 'CIV', 2)])
    assert dal.select_person(2) == { 'id':2, 'name':'BLAND', 'fname':'CELINA', 'rank':'CIV' }
    assert dal.delete_person(2)

    assert dal.select_menu(1) == { 'id':1, 'date':'2022-12-01', 'menu':"canard confis à l'orange" }
    assert dal.select_menu(2) == {}
    assert dal.insert_menu([('2022-12-02', "sanglier aux cèpes")])
    assert dal.insert_menu([('2022-12-02', "sanglier aux cèpes")]) == False
    assert dal.select_menu(2) == { 'id':2, 'date':'2022-12-02', 'menu':"sanglier aux cèpes" }
    assert dal.select_motw('2022-12-01', '2022-12-02') == [{'id':1, 'date':'2022-12-01', 'menu':"canard confis à l'orange"}, {'id':2, 'date':'2022-12-02', 'menu':"sanglier aux cèpes"}]
    assert dal.select_motw('2020-12-01', '2020-12-02') == []
    assert dal.select_motd('2022-12-01') == [{'id':1, 'date':'2022-12-01', 'menu':"canard confis à l'orange"}]
    assert dal.select_motd('2022-12-05') == []
    assert dal.update_menu([('2022-12-03', "coq au vin", 2)])
    assert dal.select_menu(2) == { 'id':2, 'date':'2022-12-03', 'menu':"coq au vin"}

    assert dal.insert_order([(1,1)]) == False
    assert dal.select_ootw(1, '2022-12-01', '2022-12-05') == [{'IDorder': 1, 'IDmenu': 1, 'received': None}]
    assert dal.insert_order([(1,2)])
    assert dal.update_order([("12:11:00",2)])
    assert dal.select_ootw(1, '2022-12-01', '2022-12-05') == [{'IDorder': 1, 'IDmenu': 1, 'received': None}, {'IDorder': 2, 'IDmenu': 2, 'received': '12:11:00'}]
    assert dal.delete_order(2)
    assert dal.delete_menu(2)
    assert dal.select_ootw(2, '2022-12-01', '2022-12-05') == []
    assert dal.select_ootd('2022-12-01') == [ { 'name':'DUFOUR', 'fname':'ALEX', 'rank':'ADJ', 'received':None } ]
    assert dal.select_ootd('2020-12-01') == []
    assert dal.select_ootw(1, '2022-12-01', '2022-12-05') == [ { 'IDorder':1, 'IDmenu':1, 'received':None } ]

    dal.close()
