#!/usr/bin/env python3
# coding: utf-8

"""
    @file   kitchen.py
	@brief	projet emess, visualisation des repas perçus

    @version   1.0
    @author    PG
    @date      04/06/2022
    @remark
"""

from flask import Flask, render_template, request
from datetime import datetime
import time
import read_message as i10n
import dal as dal


app = Flask(__name__, template_folder='tpl')

@app.route('/', methods=['GET'])
def index():
    """ home page """
    try:
        lang = request.args['lang']
    except KeyError:
        lang = "fr"
    try:
        display = request.args['display']
    except KeyError:
        display = "none"

    msg  = i10n.message_read(lang)
    data = dal.DAL("./data/emess")

    dt    = datetime.now()     # get current datetime
    today = str(dt).split(' ')[0]

    posts  = []
    for order in data.select_ootd(today):
        icon = "person_identity" if order['rank'] == "CIV" else "person"
        name = order['name'] + " " + order['fname']
        received = "thumb_up" if order['received'] == None else ''
        posts.append({'icon':icon, 'name':name, 'received':received})

    return render_template(
        "kitchen.html",
        lang=lang, title=msg['MSG_TITLE'], posts=posts)

#main
app.run(port=5002, debug=True)
