#!/usr/bin/env python3
# coding: utf-8

"""
    @file   tablet.py
	@brief	projet emess, réservation repas

    @version   1.0
    @author    PG
    @date      04/06/2022
    @remark
"""

from flask import Flask, render_template, request
from datetime import datetime
import time
import read_message as i10n
import dal as dal
import date as calendar


app = Flask(__name__, template_folder='tpl')

@app.route('/', methods=['GET'])
def index():
    """ home page """
    try:
        lang = request.args['lang']
    except KeyError:
        lang = "fr"
    try:
        display = request.args['display']
    except KeyError:
        display = "none"

    msg = i10n.message_read(lang)

    return render_template(
        "tablet.html",
        lang=lang, title=msg['MSG_TITLE'], input=msg['MSG_INPUT'], login=msg['MSG_LOGIN'], 
        badident=msg['MSG_ERRIDENT'], display=display)

@app.route('/form_id', methods=['POST'])
def menu_select():
    """ menus de la semaine """
    lang  = request.form['lang']
    badge = request.form['badge']

    msg   = i10n.message_read(lang)
    data  = dal.DAL("./data/emess")
    row   = {}
    try:
        row = data.select_person(int(badge))
    except ValueError:
        pass
    if row == {}:
        return render_template(
            "tablet.html",
            lang=lang, title=msg['MSG_TITLE'], input=msg['MSG_INPUT'], login=msg['MSG_LOGIN'],
            badident=msg['MSG_ERRIDENT'], display="block")
    
    # identification OK
    def get_menu(menus: dict, date : str) -> tuple:
        """ donne le menu du jour """
        for menu in menus:
            if menu['date'] == date:
                return menu['id'], menu['menu']
        return 0, ''
    
    def get_order(orders: dict, IDmenu : int) -> tuple:
        """ donne la commande du client """
        for order in orders:
            if order['IDmenu'] == IDmenu:
                if order['received'] == None:
                    return order['IDorder'], "checked", ''
                else:
                    return order['IDorder'], "checked", "thumb_up"
        return 0, '', ''
    
    dates  = calendar.get_dotw()
    menus  = data.select_motw(dates[0], dates[4])
    orders = data.select_ootw(row['id'], dates[0], dates[4])
    days   = msg['MSG_DAYS'].split(',')
    day    = 0
    
    posts  = []
    for date in dates:
        today = str(datetime.now()).split(' ')[0]
        IDmenu,  menu = get_menu(menus, date)
        IDorder, checked, received = get_order(orders, IDmenu)
        disabled = "disabled" if IDmenu == 0 or date <= today else ''
        posts.append({'day':days[day], 'IDmenu':IDmenu, 'IDorder':IDorder, 'checked':checked, 'disabled':disabled, 'menu':menu, 'received':received})
        day += 1

    return render_template(
        "motw.html",
        lang=lang, title=msg['MSG_TITLE'], badge=row['id'], name=row['rank']+" "+row['fname']+" "+row['name'], posts=posts,
        validate=msg['MSG_VALIDATE'])

@app.route('/form_validate', methods=['POST'])
def menu_validation():
    """ enregistrements repas """
    lang  = request.form['lang']
    badge = request.form['badge']

    msg   = i10n.message_read(lang)
    data  = dal.DAL("./data/emess")

    try:    # validation
        if request.form['submit'] == "submit":
            for day in msg['MSG_DAYS'].split(','):
                idmenu  = request.form[day] if request.form.get(day) else 0
                idorder = request.form['order_'+day] if request.form.get('order_'+day) else 0
                if int(idmenu):
                    data.insert_order([(badge, idmenu)])
                elif int(idorder):
                    data.delete_order(idorder)
    except KeyError:
        pass

    row = {}
    try:
        row = data.select_person(int(badge))
        display = "block" if row == {} else "none"
    except ValueError:
        display = "none"
        
    return render_template(
        "tablet.html",
        lang=lang, title=msg['MSG_TITLE'], input=msg['MSG_INPUT'], login=msg['MSG_LOGIN'],
        badident=msg['MSG_ERRIDENT'], display=display)

#main
app.run(port=5001, debug=True)
