#!/usr/bin/env python3
# coding: utf-8

"""
    @file   setup.py
    @brief  initialisation de la base de données

    @version   1.0
    @author    BC
    @date      04/06/2022
    @remark
"""

import sqlite3

DATABASE = "emess"

dbh    = None
cursor = None

def create_database(database : str) -> bool:
    """ connexion à la base de données """
    global dbh, cursor

    try:
        dbh    = sqlite3.connect("../2-serveur/data/"+database+".db")
        cursor = dbh.cursor()
    except Error as err:
        print(err)
        return False
    return True

def fetch_database():
    """ peuplement de la base """
    global dbh, cursor

    cursor.execute(
    	"CREATE TABLE if not exists `personnels` ( \
            `ID`		INTEGER PRIMARY KEY, \
            `nom`		varchar(20) not NULL, \
            `prenom`	varchar(20) not NULL, \
            `grade`	    varchar(3) not NULL, \
            CHECK (nom <> ''), \
            CHECK (prenom <> ''), \
            CHECK (grade <> ''), \
            UNIQUE(nom, prenom) \
            )"
    	)

    data = [
    	('DUFOUR', 'ALEX', 'ADJ'),
    	]

    cursor.executemany("insert into personnels values(NULL, ?, ?, ?)", data)
    dbh.commit()

    cursor.execute(
    	"CREATE TABLE if not exists `menus` ( \
            `ID`		INTEGER PRIMARY KEY, \
            `date`	    DATE not NULL, \
            `menu`	    varchar(40) not NULL, \
            CHECK (menu <> ''), \
            UNIQUE(date) \
            )"
    	)

    data = [
    	('2022-12-01', 'canard confis à l\'orange'),
    	]

    cursor.executemany("insert into menus values(NULL, ?, ?)", data)
    dbh.commit()

    cursor.execute(
    	"CREATE TABLE if not exists `reservations` ( \
            `ID`		    INTEGER PRIMARY KEY, \
            `IDpersonnel`   unsigned int not NULL, \
            `IDmenu`        unsigned int not NULL, \
            `reception`	    date, \
            UNIQUE(IDpersonnel, IDmenu), \
            FOREIGN KEY(IDpersonnel) REFERENCES personnels(ID), \
            FOREIGN KEY(IDmenu) REFERENCES menus(ID) \
            )"
    	)

    data = [
    	(1, 1),
    	]

    cursor.executemany("insert into reservations values(NULL, ?, ?, NULL)", data)
    dbh.commit()

def close_database():
    global dbh, cursor
    cursor.close()
    dbh.close()

if create_database(DATABASE):
    fetch_database()
    close_database()
